#
# spec file for package multimon-ng
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2017-2024, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           multimon-ng
Version:        1.3.1
Release:        1.1
Summary:        A fork of multimon that decodes multiple digital transmission modes
License:        GPL-2.0-only
Group:          Productivity/Hamradio/Other
URL:            https://github.com/EliasOenal/multimon-ng
Source:         https://github.com/EliasOenal/multimon-ng/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(x11)
Recommends:     sox

%description
MultimonNG a fork of multimon. It decodes the following digital transmission modes:
* POCSAG512 POCSAG1200 POCSAG2400
* EAS
* UFSK1200 CLIPFSK AFSK1200 AFSK2400 AFSK2400_2 AFSK2400_3
* HAPN4800
* FSK9600
* DTMF
* ZVEI1 ZVEI2 ZVEI3 DZVEI PZVEI
* EEA EIA CCIR
* MORSE CW
* FLEX

%prep
%setup -q

%build
%cmake
%make_jobs

%install
%cmake_install

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_mandir}/man1/multimon-ng.1%{?ext_man}

%changelog
* Sat Jun 29 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.3.1
  * Fixed subsampling issues when piping chunked data.
  * Fixed format string in FLEX decoder.
* Mon Jan 29 2024 Dirk Müller <dmueller@suse.com>
- update to 1.3.0:
  * POCSAG: Support for the Danish charset.
  * FLEX: Fixed incorrect use of format string.
* Wed Oct 19 2022 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.2.0
  * Separated FLEX and FLEX_NEXT. The former is identical to 1.1.9,
    while FLEX_NEXT gained new features, as well as known
    regressions. (See #168)
  * Several smaller POCSAG fixes.
  * Fix for opening large wav files with improper header.
* Tue Sep 22 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.1.9
  * multimon-ng now has a man page, let's try to keep it updated.
  * FLEX: Changes to group messages and delimiters.
  * FMS: Fixed a problem with the direction of telegrams.
  * POCSAG: Support for the Slovenian charset.
* Tue Jul  2 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.1.8
  * POCSAG: Support for the Swedish charset, as well as smaller
    fixes. The decoder now by default detects the message type
    according to the POCSAG standard, use "-f auto" to enable the
    old behaviour of heuristically detecting the type.
  * FLEX: Numeric messages now won't have spaces stripped anymore.
  * DTMF: Filter false positives.
* Tue Jan 15 2019 mardnh@gmx.de
- Update to version 1.1.7+git.20190115:
  * version 1.1.7
  * Fix typo
  * Fix frament idetification
  * Add a charset option for POCSAG demodulators
* Sun Nov 18 2018 Jan Engelhardt <jengelh@inai.de>
- Grammar fix in summary.
* Wed Oct 17 2018 mardnh@gmx.de
- Update to version 1.1.6+git.20181017:
  * version 1.1.6
  * Add a stub replacement for BCHCode.c
  * Restore copyright notice from bch3121.c
  * Restore FSF notice on the FLEX decoder derived from GNU Radio
* Fri Jun  1 2018 mardnh@gmx.de
- Update to version 1.1.5+git.20180527:
  * Restore FSF copyright notices on win32_getopt.[ch]
  * Version 0.8.7v (11 APR 2018)
  * Modification (to this file) made by Bruce Quinton and Rob0101
    (as seen on github: https://github.com/rob0101)
  * Issue *95 created by rob0101: '-a FLEX dropping first character
    of some message on regular basis'
  * Implemented Rob0101's suggestion of K, F and C flags to indicate
    the message fragmentation:
    'K' message is complete and O'K' to display to the world.
    'F' message is a 'F'ragment and needs a 'C'ontinuation message
    to complete it.
    Message = Fragment + Continuation  *         'C' message is a
    'C'ontinuation of another fragmented message
  * I missed a null terminator on the 'Message' array and therefore
    was printing garbage to the output. Fixed now!
  * Addressed issue #101: group messaging misbehaving when the
    message frame is a corrupt packet.
  * Version 0.9.0v (22 May 2018) Modification (to this file) made
    by Bruce Quinton (zanoroy@gmail.com) - Addded Define at top of
    file to modify the way missed group messages are reported in
    the debug output (default is 1; report missed capcodes on the
    same line) REPORT_GROUP_CODES   1 // Report each cleared faulty
    group capcode : 0 = Each on a new line; 1 = All on the same line;
* Mon Apr  2 2018 mardnh@gmx.de
- Update to version 1.1.5+git.20180402:
  * Implemented chzchzchz's fix for 'processing unfragmented FLEX messages, multimon-ng produces corrupted messages'
  * x10: fix various compiler warnings
  * Revert "Issue #78 - Found a problem in the length detection sequence, modified the if statement to ensure the message length is"
  * Revert "Revert "Issue #78 - Found a problem in the length detection sequence, modified the if statement to ensure the message length is""
  * Issue #87 created by bertinhollan:
  * fix for EAS issue #94
  * silenced debug message
  * Comment out includes for sys/wait and sys/resource
  * Fix event polling loop with SCOPE demodulator
  * cleaned up unused x10 includes
  * version 1.1.5
* Mon Dec 18 2017 mpluskal@suse.com
- Update dependencies
* Fri Oct 20 2017 mardnh@gmx.de
- Update to version 1.3.0+git.20171016:
  * flex: don't drop first message characters in alphanumeric parsing
  * fix compilation warnings
  * Issue #78 - Found a problem in the length detection sequence, modified the if statement to ensure the message length is only checked for Aplha messages, the other types calculate thier length while decoding
  * Added version info to the top of the demod_flex.c file after the previous updates to the code. I should have done it a while ago. see last commits for the actual updates.
  * Change debug level on Found Long address message to be 4, outside of the normal range as only I need it at the moment..
  * An issue with group messaging has been identified, the long address handling seems to be hit and miss. modified the demod_flex.c code to ignore the flag while decoding gorup messages
  * Fixed CMake build, bumped version and updated README.
  * Found a code flow issue (identified by: bertinholland issue #74 within EliasOenal's master multimon-ng branch) I was checking for the end of the message block on group messages before splitting the message, therefore incorrectly identified the end block as an Invlaid OFfset.
  * Add sample script which can decode multiple pager channels in parallel.
  * work in progress
  * code to demodulate X10RF signals
* Sun Oct  1 2017 mardnh@gmx.de
- Update to version 1.3.0+git.20170901:
  * Update Flex Code
  * Fixed handling of Numeric Only messages
  * Version number and Group Messaging (fix)
  * Added Debugging, removed multiple loops
  * Version rolled, added debugging and improved CPU usage slightly
  * Group Message fix
  * Updated demod_flex.c (Changed GPN back to ALN)
  * simplify code and remove buffers for timestamps
  * cleanup
* Fri Sep  1 2017 mardnh@gmx.de
- Update to version 1.2.0+git.20170901:
  * Add --label / -l which prefixes lines with text
  * Fix indent.
  * Just store the label pointer rather that allocating memory etc.
  * Print label even when --timestamp isn't used.
  * without make install, buildroot breaks..
  * Fixed --label implementation
- Remove patch:
  * multimon-ng-makefile-add-make-install.diff (fixed upstream)
* Tue Jul 18 2017 mardnh@gmx.de
- Update to version 1.2.0+git.20170718:
  * Adapting vehicle-id from dec to hex
  * Update Flex Code
  * Fixed handling of Numeric Only messages
  * Version number and Group Messaging (fix)
  * Added Debugging, removed multiple loops
  * Version rolled, added debugging and improved CPU usage slightly
  * Group Message fix
  * Updated demod_flex.c (Changed GPN back to ALN)
  * add timestamp option
  * add usage descritpion for time stamp option
  * simplify code and remove buffers for timestamps
  * cleanup
* Wed Mar 22 2017 mardnh@gmx.de
- Update to version 1.1.0.git1489481434.9408b02:
  * Update fms.c
  * FLEX: Fix type errors on aarch64
  * Fix pulse-simple linking to find_library() it first in case it's not in default search path
* Sun Aug 28 2016 mardnh@gmx.de
- Update to version 1.1.0.git1472378460.e88b22f:
  * Basic fixes to get FLEX decoder working for 3200 baud.
  * Clean up the FLEX decoder a little bit to work on 32-bit targets.
  * Fix failed inlinings resulting in linker errors
  * Fallback if __builtin_popcount isn't available
  * White Space: replace spaces with tabs
* Thu Mar  3 2016 mardnh@gmx.de
- Update to version 1.1.0.git1457005494.6d75ea1:
  + fixed dumpcsv warning and removed superfluous includes
* Mon Nov  9 2015 mardnh@gmx.de
- Update to version 1.1.0.git1447073843.04847c5:
  + Add support for FLEX pager protocol to multimon-ng
  + Added FLEX to list of supported protocols in README
  + Corrected sign of slicer
  + Tuned FLEX locking params to avoid lock on POC1200
  + Corrected long integer declarations
  + Fix include for X11 on FreeBSD
  + updated readme
* Sun May 17 2015 mardnh@gmx.de
- Update to version 0.0.0.git1431688037.4cc984f:
  + Update fms.c
* Wed Jan 14 2015 mardnh@gmx.de
- Update to version 0.0.0.git1417245058.538a758:
  + Add FMS decoder by copying the CLIP decoder
  + Add forgotten files to project file
  + Rename file
  + Fix variable naming ...
  + Avoid duplicate function naming ...
  + Avoid duplicate function naming ...
  + Avoid duplicate function naming ...
  + Make the FMS decoder basically work
  + Fix bit inversion
  + Use one bit less for synchronisation
  + Rewrite the rest to reverse bit direction and make output a little more verbose
  + Use verbosity levels in a sane way and make output more useful
  + Remove FMS gen
  + Really revert gen* stuff
  + Also revert unintended changes in multimon.h
  + expanded a comment
  + Fix compilation error
  + Add a basic CRC check (no automatic data correction on CRC errors yet
  + Prepare for correction on wrong CRC
  + Remove no longer needed parameter
  + Implement fixing one bit errors (assuming the CRC is correct?)
  + multimon-ng: added build for building with cmake
* Mon Aug 11 2014 mardnh@gmx.de
- Update to version 0.0.0+git.1396234264.6119707:
  + Compiler warning cleanup
  + pay heed to the quietflg
  + Substituted u_int with unsigned int to avoid posix dependencies
  + FreeBSD fixed
  + ufsk1200 example
  + proper handling of corrupt messages
  + Changed <CORRUPT> tags and moved them to -v2. New POCSAG settings and improvements.
  + parameter -p shows partial decodes. improved type detection heuristic.
  + option to utilize heuristic to prune likely false positive decodes
* Tue Sep  3 2013 mardnh@gmx.de
- initial version
